#
# spec file for package ghc-conduit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name conduit
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.2.12.1
Release:        lp150.3.1
Summary:        Streaming data processing library
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-lifted-base-devel
BuildRequires:  ghc-mmorph-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-split-devel
%endif

%description
`conduit` is a solution to the streaming data problem, allowing for production,
transformation, and consumption of streams of data in constant memory.
It is an alternative to lazy I/O which guarantees deterministic resource
handling.

For more information about conduit in general, and how this package in
particular fits into the ecosystem, see [the conduit
homepage](https://github.com/snoyberg/conduit#readme).

Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/conduit>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Wed Oct 11 2017 psimons@suse.com
- Update to version 1.2.12.1.
  A more detailed change log is not available.
* Wed Sep 13 2017 psimons@suse.com
- Update to version 1.2.12.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 1.2.11.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 1.2.10 with cabal2obs.
* Sun Apr  9 2017 psimons@suse.com
- Update to version 1.2.9.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.2.9 with cabal2obs.
* Sat Oct  1 2016 psimons@suse.com
- Update to version 1.2.8 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 1.2.7 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.6.6 revision 0 with cabal2obs.
* Sat May  7 2016 mimi.vx@gmail.com
- update to 1.2.6.6
  * Fix test suite compilation on older GHCs
  * In zipConduitApp, left bias not respected mixing monadic and non-monadic conduits
* Sat Mar 12 2016 mimi.vx@gmail.com
- update to 1.2.6.4
  * fix benchmark by adding typesignature
* Mon Mar  7 2016 mimi.vx@gmail.com
- update to 1.2.6.3
* Mon Feb 15 2016 mimi.vx@gmail.com
- update to 1.2.6.2
  * resourcet cannot be built with GHC 8
  * Remove upper bound on transformers
* Thu Dec 31 2015 mimi.vx@gmail.com
- update to 1.2.6.1
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 1.2.6
  * sourceToList
  * Canonicalise Monad instances
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 1.2.5.1
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 1.2.5
  * mapAccum and mapAccumM should be strict in their state
  * Some documentation improvements
* Wed Apr 22 2015 mimi.vx@gmail.com
- update to 1.2.4
  * [fuseBothMaybe](https://github.com/snoyberg/conduit/issues/199)
* Sun Feb  1 2015 mpluskal@suse.com
- Update to 1.2.3.1:
  + Refactoring into conduit and conduit-extra packages. Core
    functionality is now in conduit, whereas most common helper
    modules (including Text, Binary, Zlib, etc) are in
    conduit-extra. To upgrade to this version, there should only be
    import list and conduit file changes necessary.
  + Two performance
    optimizations added. (1) A stream fusion framework. This is a non-breaking
    change. (2) Codensity transform applied to the `ConduitM` datatype. This only
    affects users importing the `.Internal` module. Both changes are thoroughly
    described in the following to blog posts: [Speeding up
    conduit](https://www.fpcomplete.com/blog/2014/08/iap-speeding-up-conduit), and
    [conduit stream
    fusion](https://www.fpcomplete.com/blog/2014/08/conduit-stream-fusion).
  + Lots more stream fusion.
  + Expose `connect` and `fuse` as synonyms for `$$` and `=$=`, respectively.
* Sun Oct  6 2013 sbahling@suse.com
- Initial package - version 1.0.7.4
